#!/bin/sh

# Since iChat has a common source base for Jaguar and Panther, to restrict the binaries to 
# the appropriate versions of the OS, we modify the Info.plist at build time.  
# This script will insert the correct value of LSMinimumSystemVersion based on the OS used
# when the project is built in B&I.

plistfile=$TARGET_BUILD_DIR/$PRODUCT_NAME.app/Contents/Info.plist

# don't insert the key if it's already there!
grep "LSMinimumSystemVersion" $plistfile > /dev/null
if [ $? = 0 ] ; then
    exit 0;
fi

linecount=`wc -l $plistfile | tr -s ' ' | cut -d\  -f2`

countminus2=`expr $linecount - 2`

# it's safe to write here in the build environment
tempfile="/$OBJROOT/plist.$$"

# chop off the last two lines of the plist
head -$countminus2 $plistfile > $tempfile

# tack on the appropriate key and value at the bottom
# of the plist
echo "	<key>LSMinimumSystemVersion</key>" >> $tempfile

if [ "$RC_RELEASE" = "Panther" ] ; then
echo "	<string>10.3</string>" >> $tempfile
else
echo "	<string>10.2.5</string>" >> $tempfile
fi

# append the last two lines we chopped off
echo "</dict>" >> $tempfile
echo "</plist>" >> $tempfile

# the final result
mv $tempfile $plistfile
